package by.zerg.pschallengesutil.model;

import static by.zerg.pschallengesutil.model.Config.*;

import java.awt.Desktop;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.net.URI;

import org.apache.log4j.Logger;

public class PSChallengesUtil {
	private static final Logger LOG = Logger.getLogger(PSChallengesUtil.class);

	protected long fileSize;
	protected BufferedReader logReader;

	public PSChallengesUtil() {
		if (LOG.isDebugEnabled()) {
			LOG.debug("Initializing new instance...");
		}
		try {
			String logFileName = STATS_LOG;
			if (LOG.isDebugEnabled()) {
				LOG.debug("Calculating log file size...");
			}
			fileSize = new File(logFileName).length();
			if (LOG.isDebugEnabled()) {
				LOG.debug("Log file size is " + fileSize + " bytes");
				LOG.debug("Accessing log file...");
			}
			logReader = new BufferedReader(new InputStreamReader(
					new FileInputStream(logFileName)));
			if (LOG.isDebugEnabled()) {
				LOG.debug("Log file found");
				LOG.debug("Skipping " + fileSize + " bytes...");
			}
			long skippedBytes = logReader.skip(fileSize);
			if (LOG.isDebugEnabled()) {
				LOG.debug(skippedBytes + " bytes skipped");
			}
		} catch (Throwable t) {
			LOG.error("Initialization error!", t);
			System.exit(1);
		}
		if (LOG.isDebugEnabled()) {
			LOG.debug("New instance successfully initialized");
		}
	}

	protected void performTask() {
		// do nothing here
	}

	public void start() {
		if (LOG.isDebugEnabled()) {
			LOG.debug("Looking for challenges url...");
		}
		String newString = null;
		for (;;) {
			try {
				newString = logReader.readLine();
			} catch (Throwable t) {
				System.exit(1);
			}
			if (newString != null) {
				if (newString.startsWith("https://pokerlibre.com/")) {
					if (LOG.isDebugEnabled()) {
						LOG.debug("New challenges url found: " + newString);
						LOG.debug("Opening new challenges url...");
					}
					try {
						Desktop.getDesktop().browse(new URI(newString));
						if (LOG.isDebugEnabled()) {
							LOG.debug("Url opened");
						}
					} catch (Throwable t) {
						LOG.warn("Exception on opening url!", t);
					}
					performTask();
				}
			} else {
				try {
					Thread.sleep(IDLE_TIME);
				} catch (Throwable t) {
					LOG.warn("Exception on thread sleep!", t);
				}
			}
		}
	}
}
